This crate contains kube-rs compatible bindings for Kubernetes custom resources for the apps.clusternet.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
apps.clusternet.io/v1alpha1
BaseDescriptionFeedInventoryGlobalizationHelmChartHelmReleaseLocalizationManifestSubscription